@@ -249,7 +249,7 @@ plotDeviationsBoxes <- function(data, observed, smoothed, x.factor,
                                      facet.labeller = facet.labeller, 
                                      facet.scales = scales.box, 
                                      angle.x = angle.x.box,
-                                     df = degfree, ggplotFuncs = ggplotFuncsDevnBoxes,
+                                     ggplotFuncs = ggplotFuncsDevnBoxes,
                                      printPlot = printPlot)
           plts[[k]][["absolute"]][[by]] <- plt[["absolute"]]
           plts[[k]][["relative"]][[by]] <- plt[["relative"]]
@@ -1270,7 +1270,9 @@ predict.pSpline <- function(object, x, npspline.segments, deriv = 0, ...)
               x.pred <- x.pred[1:y.nonmiss[length(y.nonmiss)]]
             y.nonmiss <- diff(y.nonmiss)
             if (any(y.nonmiss >= 3))
-              warning("There are runs of 3 or more contiguous y values that are missing")
+              warning(paste("smoothSpline has found runs of 3 or more contiguous", 
+                            "missing y-values - is the current na.y.action setting,", 
+                            paste0("`", na.act.y,"', appropriate?")))
           } else
             x.pred <- NULL
         }
@@ -1713,6 +1715,17 @@ predict.pSpline <- function(object, x, npspline.segments, deriv = 0, ...)
         stop("the smoothing.segments are not a set of non-overlapping, successive intervals")
     }
     
+    #Check that for overlapping smoothing segments and give an error or a warning depending on get.rates
+    if (!all(diff(unlist(smoothing.segments)) > 0))
+    { 
+      if (!("none" %in% get.which))
+        stop("rates.method must be `none` when times values occur in more than one smoothing segment")
+      else
+        warning("The values for some times occur in multiple smoothing segments and so some individuals ",
+                "will have multiple rows in the returned data.frame, one for each segment in which the ",
+                "times occur.")
+    }
+    
     v <- unique(id.cols)
     v <- setdiff(v, c("Type","TunePar","TuneVal","Tuning","Method")) #remove names yet to come
     
